<?php
if (!defined('ABSPATH')) {
  exit;
}

add_action('admin_menu', 'custom_shipping_service_plugin_menu');

function custom_shipping_service_plugin_menu()
{
  add_menu_page(
    __('Configurações do Plugin de Serviço de Envio', 'woocommerce-shipping-service-plugin'),
    __('VestApp Configurações', 'woocommerce-shipping-service-plugin'),
    'manage_options',
    'mapp-shipping-settings',
    'custom_shipping_service_settings_page',
    'https://storage.googleapis.com/clientesmapptools/7419f92826922207b90555b05883e12d.png'
  );
}

function custom_shipping_service_settings_page()
{
  if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["save_settings"])) {
    try {
      update_option('calculate_service_token', sanitize_text_field($_POST['calculate_service_token']));
      update_option('record_service_token', sanitize_text_field($_POST['record_service_token']));
      update_option('status_service_token', sanitize_text_field($_POST['status_service_token']));
      update_option('client_code', sanitize_text_field($_POST['client_code']));

      // frete gratis
      update_option('frete_gratis_checkbox', isset($_POST['frete_gratis']) ? true : false);
      update_option('frete_gratis_valor_minimo', sanitize_text_field($_POST['valor_minimo_frete_gratis']));

      // exibir mensagem de sucesso
      echo '<div class="notice notice-success is-dismissible">';
      echo '<p>' . __('Configurações salvas com sucesso!', 'woocommerce-shipping-service-plugin') . '</p>';
      echo '</div>';
    } catch (\Throwable $th) {
      // exibir mensagem de erro
      echo '<div class="notice notice-error is-dismissible">';
      echo '<p>' . __('Erro ao salvar as configurações.', 'woocommerce-shipping-service-plugin') . '</p>';
      echo '</div>';
    }
  }

  // $calculate_service_token = get_option('calculate_service_token');
  // $record_service_token = get_option('record_service_token');
  // $status_service_token = get_option('status_service_token');
  $calculate_service_token = "8d3bc2581ed4705781e7001036b0c156-calcular";
  $record_service_token = "8d3bc2581ed4705781e7001036b0c156-gravar";
  $status_service_token = "8d3bc2581ed4705781e7001036b0c156-status";
  $client_code = get_option('client_code');
  $frete_gratis_checkbox = get_option('frete_gratis_checkbox');
  $frete_gratis_valor_minimo = get_option('frete_gratis_valor_minimo');
?>
  <div class="wrap">
    <h1><?php _e('Configurações do Plugin de Serviço de Envio', 'woocommerce-shipping-service-plugin'); ?></h1>

    <form method="post" action="">
      <table class="form-table">
        <h2><?php _e('Tokens de configuração', 'woocommerce-shipping-service-plugin'); ?></h2>
        <tr style="display: none">
          <th scope="row"><label for="calculate_service_token"><?php _e('Token de Calcular Serviço', 'woocommerce-shipping-service-plugin'); ?></label></th>
          <td>
            <input type="text" name="calculate_service_token" id="calculate_service_token" value="<?php echo esc_attr($calculate_service_token); ?>" class="regular-text">
          </td>
        </tr>
        <tr style="display: none">
          <th scope="row"><label for="record_service_token"><?php _e('Token de Gravar Serviço', 'woocommerce-shipping-service-plugin'); ?></label></th>
          <td>
            <input type="text" name="record_service_token" id="record_service_token" value="<?php echo esc_attr($record_service_token); ?>" class="regular-text">
          </td>
        </tr>
        <tr style="display: none">
          <th scope="row"><label for="status_service_token"><?php _e('Token de Status do Serviço', 'woocommerce-shipping-service-plugin'); ?></label></th>
          <td>
            <input type="text" name="status_service_token" id="status_service_token" value="<?php echo esc_attr($status_service_token); ?>" class="regular-text">
          </td>
        </tr>
        <tr>
          <th scope="row"><label for="client_code"><?php _e('Código do Cliente', 'woocommerce-shipping-service-plugin'); ?></label></th>
          <td>
            <input type="text" name="client_code" id="client_code" value="<?php echo esc_attr($client_code); ?>" class="regular-text">
          </td>
        </tr>
      </table>
      <hr />
      <!-- ativar ou desativar frete gratis apartir de um valor -->
      <table class="form-table">
        <h2><?php _e('Controle de Frete: Ative ou Desative Frete Grátis a Partir de um Valor', 'woocommerce-shipping-service-plugin'); ?></h2>
        <tr>
          <th scope="row"><label for="frete_gratis"><?php _e('Ativar Frete Grátis', 'woocommerce-shipping-service-plugin'); ?></label></th>
          <td>
            <input type="checkbox" name="frete_gratis" id="frete_gratis" class="regular-text" <?= isset($frete_gratis_checkbox) && $frete_gratis_checkbox == true  ? 'checked="true"' : '' ?>>
          </td>
        </tr>
        <tr>
          <th scope="row"><label for="valor_minimo_frete_gratis"><?php _e('Valor Mínimo para Frete Grátis', 'woocommerce-shipping-service-plugin'); ?></label></th>
          <td>
            <input type="number" name="valor_minimo_frete_gratis" id="valor_minimo_frete_gratis" value="<?= !empty($frete_gratis_valor_minimo) ? esc_attr($frete_gratis_valor_minimo) : '' ?>" class="regular-text" disabled>
          </td>
        </tr>
      </table>
      <p class="submit">
        <input type="submit" name="save_settings" class="button-primary" value="<?php _e('Salvar Configurações', 'woocommerce-shipping-service-plugin'); ?>">
      </p>
    </form>
  </div>
  <script>
    if (document.getElementById('frete_gratis').checked) {
      document.getElementById('valor_minimo_frete_gratis').disabled = false;
    }
    document.getElementById('frete_gratis').addEventListener('change', function() {
      document.getElementById('valor_minimo_frete_gratis').disabled = !this.checked;
    });
  </script>
<?php
}

function all_required_fields_filled()
{
  if (
    empty(get_option('client_code')) ||
    empty(get_option('calculate_service_token')) ||
    empty(get_option('record_service_token')) ||
    empty(get_option('status_service_token'))
  ) {
    return false;
  }

  return true;
}

add_action('admin_notices', 'show_admin_notice_for_settings');

function show_admin_notice_for_settings()
{
  if (!all_required_fields_filled()) {
    echo '<div class="notice notice-error" style="border-left: 4px solid #dc3232; padding: 10px; font-size: 14px;">';
    echo '<span class="dashicons dashicons-warning" style="color: #dc3232; margin-right: 5px;"></span>';
    _e('Por favor, preencha todos os campos do plugin VestApp Entregas.', 'woocommerce-shipping-service-plugin');
    echo '</div>';
  }
}
