<?php
if (!defined('ABSPATH')) {
  exit;
}

function get_address_details_from_api($cep)
{
  $api_url = "https://brasilapi.com.br/api/cep/v1/{$cep}";

  $response = custom_curl_request($api_url, [], [], 'GET');

  if (!isset($response['response'])) {
    return false;
  }

  $body = $response['response'];
  if (!is_array($body)) {
    $body = json_decode($body, true);
  }

  return $body;
}

function calculate_shipping_cost($cep_destino)
{
  $calculate_service_token = get_option('calculate_service_token');
  $codCliente = get_option('client_code');

  // Obter os detalhes do endereço da API BrasilAPI
  $address_details = get_address_details_from_api($cep_destino);

  if ($address_details && isset($address_details['cep']) && isset($address_details['street'])) {

    $shipping_point = array(
      'rua' => $address_details['street'],
      'numero' => isset($address_details['number']) ? $address_details['number'] : '',
      'bairro' => $address_details['neighborhood'],
      'cidade' => $address_details['city'],
      'uf' => $address_details['state'],
      'cep' => $address_details['cep']
    );

    // Dados para a solicitação POST.
    $request_data = array(
      'token' => $calculate_service_token,
      'codCliente' => $codCliente,
      'pontos' => array(
        // $company_address,
        $shipping_point
      ),
      'retorno' => 'N',
      'tipoCalculo' => 'faixaCep'
    );

    // Realizar a requisição para calcular o frete.
    $api_url = 'https://vestappentregas.com.br/integracao';
    $response = custom_curl_request($api_url, $request_data);

    if (!isset($response['response']) || !isset($response['response']['Sucesso'])) {
      return false;
    }

    $shipping_cost = $response['response'];
    if (!is_array($shipping_cost)) {
      $shipping_cost = json_decode($shipping_cost, true);
    }

    if (isset($shipping_cost['Sucesso'])) {
      $valor = $shipping_cost['Sucesso']['valor'];
      $distancia = $shipping_cost['Sucesso']['distancia'];
      $tempo = $shipping_cost['Sucesso']['tempo'];

      // Retornar os dados de custo de envio.
      return array(
        'valor' => (float) $valor,
        'distancia' => $distancia,
        'tempo' => $tempo,
      );
    } else {
      return false;
    }
  } else {
    return false;
  }
}

function save_service($shipping_address)
{
  $save_service_token = get_option('record_service_token');
  $codCliente = get_option('client_code');

  if (isset($shipping_address['address_1']) && isset($shipping_address['postcode'])) {

    // Obter os detalhes do endereço da API BrasilAPI
    $nomeCliente = $shipping_address['first_name'];
    if ($shipping_address['last_name'] != '') {
      $nomeCliente .= " " . $shipping_address['last_name'];
    }
    $phone = '';
    if (!empty($shipping_address['phone_billing'])) {
      $phone = $shipping_address['phone_billing'];
    }
    if(!empty($shipping_address['phone'])){
      $phone = $shipping_address['phone'];
    }
    $shipping_point = array(
      'rua' => $shipping_address['address_1'],
      'numero' => $shipping_address['number'],
      'complemento' => $shipping_address['address_2'],
      'bairro' => $shipping_address['neighborhood'],
      'cidade' => $shipping_address['city'],
      'uf' => $shipping_address['state'],
      'cep' => $shipping_address['postcode'],
      "telefone" => $phone,
      "procurarPor" => $nomeCliente
    );

    // Dados para a solicitação POST.
    $request_data = array(
      'token' => $save_service_token,
      'codCliente' => $codCliente,
      'Usuario' => "Plugin WooCommerce",
      'centroCusto' => "Plugin WooCommerce",
      'pontos' => array(
        $shipping_point
      ),
      'retorno' => "N",
      'formaPagamento' => "F",
      'tipoCalculo' => "faixaCep",
    );

    // Realizar a requisição para gravar o serviço.
    $api_url = 'https://vestappentregas.com.br/integracao';
    $response = custom_curl_request($api_url, $request_data);

    if (!isset($response['response']) || !isset($response['response']['Sucesso'])) {
      return false;
    }

    $save_service_result = $response['response'];
    if (!is_array($save_service_result)) {
      $save_service_result = json_decode($save_service_result, true);
    }

    if (isset($save_service_result['Sucesso'])) {
      // Retornar os detalhes do serviço gravado.
      return $save_service_result['Sucesso'];
    } else {
      return false;
    }
  } else {
    return false;
  }
}

function status_service($id_servico)
{
  $service_token = get_option('status_service_token');
  $codCliente = get_option('client_code');
  // Dados para a solicitação POST.
  $request_data = array(
    'token' => $service_token,
    'codCliente' => $codCliente,
    "servico" => $id_servico
  );

  // Realizar a requisição para gravar o serviço.
  $api_url = 'https://vestappentregas.com.br/integracao';
  $response = custom_curl_request($api_url, $request_data);

  if (!isset($response['response']) || !isset($response['response']['Sucesso'])) {
    return false;
  }

  $save_service_result = $response['response'];
  if (!is_array($save_service_result)) {
    $save_service_result = json_decode($save_service_result, true);
  }

  if (isset($save_service_result['Sucesso'])) {
    // Retornar os detalhes do serviço gravado.
    return $save_service_result['Sucesso'];
  } else {
    return false;
  }
}

function custom_curl_request($url, $data = array(), $headers = array(), $method = 'POST')
{
  $curl = curl_init();

  if ($method === 'GET' && !empty($data)) {
    $url .= '?' . http_build_query($data);
  }

  curl_setopt($curl, CURLOPT_URL, $url);
  curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
  curl_setopt($curl, CURLOPT_CUSTOMREQUEST, $method);

  if ($method === 'POST' && !empty($data)) {
    curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($data, JSON_UNESCAPED_UNICODE));
    $headers[] = 'Content-Type: application/json';
  }

  if (!empty($headers)) {
    curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
  }

  $response = curl_exec($curl);
  $http_code = curl_getinfo($curl, CURLINFO_HTTP_CODE);

  curl_close($curl);

  if (!is_array($response)) {
    $response = json_decode($response, true);
  }

  return array(
    'response' => $response,
    'http_code' => $http_code,
  );
}
