<?php
if (!defined('ABSPATH')) {
  exit;
}

add_action('woocommerce_shipping_init', 'custom_shipping_method_init');

function custom_shipping_method_init()
{
  if (!class_exists('WC_Shipping_Method_Mapp_Service')) {
    class WC_Shipping_Method_Mapp_Service extends WC_Shipping_Method
    {
      public function __construct($instance_id = 0)
      {
        $this->id                 = 'mapp_service';
        $this->title              = 'VestApp - Entregas Expressas (Entrega em 24 horas)';
        $this->instance_id        = absint($instance_id);
        $this->method_title       = __('VestApp', 'woocommerce-shipping-service-plugin');
        $this->method_description = __('VestApp baseado na API da Mapp Sistemas.', 'woocommerce-shipping-service-plugin');

        $this->supports = array(
          'shipping-zones',
          'instance-settings',
          'instance-settings-modal',
          'order'
        );

        $this->init();
      }

      public function init()
      {
        $this->instance_form_fields = array(
          'custom_settings_page' => array(
            'title' => __('Configurações principais', 'mapp_service'),
            'type' => 'title',
            'description' => sprintf(__('Clique <a href="%s">aqui</a> para acessar as configurações principais para funcionamento do plugin.', 'meu_metodo'), admin_url('admin.php?page=mapp-shipping-settings')),
          ),
          'title' => array(
            'title' => __('Título', 'mapp_service'),
            'type' => 'text',
            'description' => __('O título que o usuário vê durante o checkout.', 'mapp_service'),
            'default' => __('VestApp - Entregas Expressas (Entrega em 24 horas)', 'mapp_service'),
          )
        );
        // Load the settings API
        $this->init_form_fields(); // This is part of the settings API. Override the method to add your own settings
        $this->init_settings(); // This is part of the settings API. Loads settings you previously init.

        add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
      }

      function calculate_shipping($package = array())
      {
        $cep = $package["destination"]["postcode"];
        $label_get = $this->get_option('title');
        $label = isset($label_get) ? $label_get : $this->title;
        // variavel buscar o valor da compra 
        $cartValue = WC()->cart->get_cart_contents_total();
        $frete_gratis_checkbox = get_option('frete_gratis_checkbox');
        $frete_gratis_valor_minimo = get_option('frete_gratis_valor_minimo');
        if ($frete_gratis_valor_minimo == null) {
          $frete_gratis_valor_minimo = 0;
        }
        try {
          $shipping_cost_data = calculate_shipping_cost($cep);
          $isFreteGratis = false;
          if ($shipping_cost_data && $shipping_cost_data['valor'] == 0.01) {
            $label = $label . ": Frete Grátis.";
            $isFreteGratis =  true;
          }

          // adicionar condicao para quando ativar a opcao te ter frete gratis se atingir um valor
          if ($frete_gratis_checkbox == true && $cartValue >= $frete_gratis_valor_minimo) {
            $label = $label . ": Frete Grátis.";
            $isFreteGratis =  true;
          }

          $label_correto = ($shipping_cost_data && $shipping_cost_data['valor'] == 0) ? null : $label;

          if ($shipping_cost_data !== false) {
            $this->add_rate(array(
              'id' => $this->id . '_' . $this->instance_id,
              'label' => $label_correto,
              'cost' => $isFreteGratis ? null : $shipping_cost_data['valor'],
              'taxes' => '',
              'calc_tax' => 'per_order'
            ));
          }
        } catch (\Throwable $th) {
        }
      }
    }
  }
}

add_filter('woocommerce_shipping_methods', 'add_custom_shipping_service_method');

function add_custom_shipping_service_method($methods)
{
  $methods['mapp_service'] = 'WC_Shipping_Method_Mapp_Service';
  return $methods;
}
